@@ -1,5 +1,5 @@
 package org.jpy;
 
 interface PyObjectCleanup {
-    int cleanupOnlyUseFromGIL();
+    int threadSafeCleanup();
 }
